# coding: iso-8859-2

# ###############
# # DESCRIPTION #
# ###############

# This script changes accented characters to their "basic latin" counterparts (E.g.  -> a,  -> o).
# At the moment only the Hungarian accented characters are implemented -- you can expand the sets in the CHARS_DICT array.
# For more information run it with the -h argument: "get-basic-latin-characters.py -h".

# ##################
# # Import Modules #
# ##################

import os
import sys
import getopt
import operator

# #########################################
# # Define Global Constants And Variables #
# #########################################

SCRIPT_NAME =                str(sys.argv[0][sys.argv[0].rfind("\\")+1:]),                         # Name of the script (without path)

MAN =                        [
                             ("NAME",            "This script changes accented characters to their \"basic latin\" counterparts (E.g.  -> a,  -> o)."),
                             ("VER",             "1.0"),
                             ("SYNOPSIS",        "[OPTION]... <input>"),
                             ("DESCRIPTION",     ""),
                             ("AUTHOR",          "Written by Adam Pcs"),
                             ("REPORTING BUGS",  "Report bugs to royaljerry@gmail.com"),
                             ("COPYRIGHT",       "Copyright (C) 2007 Adam Pcs; this is free software.")
                             ]
OPTIONS_SHORT =              [
                             ("h",               "Print this message and exit."),
                             ("f",               "Take input as file."),
                             ("c <codetable>",   "Print character conversion table using <codetable> and exit (\"dos\" or \"win\")."),
                             ("v",               "Verbose mode.")
                             ]

TAB_0 =                      7                                                                     # Indent of the usage sytax descriptions before arguments when requestng help
TAB_1 =                      20                                                                    # Indent of the usage sytax descriptions after arguments when requestng help
INPUT_STRING =               sys.argv[len(sys.argv)-1]                                             # Input string reference
INPUT_STRING_OBJ =           ""                                                                    # Input string reference as object
OUTPUT_STRING =              ""                                                                    # Output string
OUTPUT_LINES =               []                                                                    # List of output string lines

CHARS_DICT =                 {
                             'a':                '',
                             'e':                '',
                             'i':                '',
                             'o':                '',
                             'u':                '',
                             'A':                '',
                             'E':                '',
                             'I':                '',
                             'O':                '',
                             'U':                ''
                             }

O_HELP =                     False                                                                 # Print this message and exit
O_FILE =                     False                                                                 # Take input as file
O_CONVTABLE =                False                                                                 # Print character conversion table using <codetable> and exit ("dos" or "win")
O_VERBOSE =                  False                                                                 # Verbose mode

# #############
# # Functions #
# #############

def printUsage(sName, man, oShort, indent0, indent1):
	# Init vars for the text to be printed
	cPrint = ""
	fChar = " "
	# Print sections and their descriptions
	for i in range(len(man)):
		nMan = man[i][0]
		if nMan == "NAME": dMan = sName + ": " + man[i][1]
		elif nMan == "SYNOPSIS": dMan = sName + " " + man[i][1]
		else: dMan = man[i][1]
		if nMan == "DESCRIPTION":
			cPrint += nMan
			# Print short descriptions
			for opt in range(len(oShort)):
				cPrint += "\n\n"
				cLine = str(fChar*TAB_0) + "-" + oShort[opt][0].ljust(indent1, " ") + oShort[opt][1]
				cPrint += cLine
		else:
			cPrint += nMan
			cPrint += "\n\n"
			cPrint += str(fChar*indent0) + dMan
		cPrint += "\n\n\n"
	print (cPrint)

def parseOptions():
	# Collect all possible short option names
	cOptsShort = ""
	for i in range(len(OPTIONS_SHORT)):
		if len(OPTIONS_SHORT[i][0]) == 1: cOptsShort += OPTIONS_SHORT[i][0] + ","
		else: cOptsShort += OPTIONS_SHORT[i][0][0:1] + ":,"
	cOptsShort = cOptsShort.rstrip(",")
	try:
		# Get current options
		opts, args = getopt.getopt(sys.argv[1:], cOptsShort)
	except getopt.GetoptError:
		# If something went wrong, print error, help information and exit
		print ("\nSomething went wrong...\n")
		printUsage(globals()["SCRIPT_NAME"][0], globals()["MAN"], globals()["OPTIONS_SHORT"], globals()["TAB_0"], globals()["TAB_1"])
		sys.exit(2)
	
	# Exit if no input specified
	if len(sys.argv) == 1:
		print ("\n" + str(globals()["SCRIPT_NAME"][0]) + " needs at least one argument...\n")
		printUsage(globals()["SCRIPT_NAME"][0], globals()["MAN"], globals()["OPTIONS_SHORT"], globals()["TAB_0"], globals()["TAB_1"])
		sys.exit(0)
	
	if O_VERBOSE: print ("")

	# Parse short options
	for op, ar in opts:
		if op == "-h": globals()["O_HELP"] =         True
		if op == "-f": globals()["O_FILE"] =         True
		if op == "-c": globals()["O_CONVTABLE"] =    ar
		if op == "-v":
			globals()["O_VERBOSE"] = True
			print ("\nEntering Verbose Mode...\n")

def printTable(charsDict, cOutput):
	print ("\nCharacter conversion table:\n")
	for oChar, cChars in charsDict.iteritems():
		if cOutput == "dos": print (oChar + " <-- " + cChars.decode("mbcs"))
		if cOutput == "win": print (oChar + " <-- " + cChars)
	print ("")

def changeChars(inputString, charsDict):
	for oChar, cChars in charsDict.iteritems():
		for c in cChars: inputString = inputString.replace(c, oChar)
	return (inputString)

def main():
	# Parse options
	parseOptions()

	if O_VERBOSE:
		print ("Print this message and exit (-h): ".ljust(70, ".") + str(O_HELP))
		print ("Take input as file (-f): ".ljust(70, ".") + str(O_FILE))
		print ("Print character conversion table and exit (-c): ".ljust(70, ".") + str(O_CONVTABLE))
		print ("Verbose mode (-v): ".ljust(70, ".") + str(O_VERBOSE))

	# Exit if help requested
	if O_HELP:
		printUsage(globals()["SCRIPT_NAME"][0], globals()["MAN"], globals()["OPTIONS_SHORT"], globals()["TAB_0"], globals()["TAB_1"])
		sys.exit(0)
	
	# Exit if character conversion table requested
	if O_CONVTABLE != False:
		printTable(CHARS_DICT, O_CONVTABLE)
		sys.exit(0)

	# Define input
	if O_FILE:
		try:
			iLinesList = open(INPUT_STRING)
			iLines = iLinesList.readlines()
			INPUT_STRING_OBJ = "".join(iLines)
		except:
			print ("Cannot open " + INPUT_STRING)
			sys.exit(2)
	else: INPUT_STRING_OBJ = INPUT_STRING
	
	# Run Filter
	result = changeChars(INPUT_STRING_OBJ, CHARS_DICT)

	# Print result
	if O_VERBOSE:
		print ("\n\n##########")
		print ("#        #")
		print ("# RESULT #")
		print ("#        #")
		print ("##########\n\n")
	print (result)
	if O_VERBOSE: print ("")

# ########
# # MAIN #
# ########

main ()

# TODO:
#
# 
